<template>
  <div class="bbsl-common-page">
    <div :class="['bbsl-table-search']">
      <div class="tabs">
        <el-tabs v-model="activeName" @tab-click="handleTabsClick">
          <el-tab-pane
            v-for="item in conditions"
            :key="item.value"
            :name="item.value"
          >
            <span slot="label" style="font-size: 14px;">
              <svgIcon
                icon-style="icon"
                :icon-class="item.icon"
                style=" vertical-align: middle;font-size: 14px;"
              />
              {{ item.name }}
            </span>
          </el-tab-pane>
        </el-tabs>
      </div>
      <div class="search">
        <el-form ref="form" @submit.native.prevent label-width="auto" inline>
          <el-form-item label="采集时间" v-if="activeName === 'history'">
            <el-date-picker
              v-model="querys[0].value"
              end-placeholder="结束日期"
              popper-class="dataTime-style"
              range-separator="至"
              start-placeholder="开始日期"
              style="width: 100%"
              type="datetimerange"
              value-format="yyyy-MM-dd HH:mm:ss"
              :clearable="false"
            />
          </el-form-item>
          <el-form-item label="设备名称">
            <el-input
              style="width: 260px"
              v-model="querys[1].value"
              placeholder="请输入设备名称"
            />
          </el-form-item>
        </el-form>
        <div>
          <el-button icon="el-icon-search" type="primary" @click="handleSearch"
            >搜索</el-button
          >
          <el-button icon="el-icon-refresh" @click="handleReset"
            >重置</el-button
          >
        </div>
      </div>
    </div>
    <div ref="contentPanel" :class="['bbsl-table-content']">
      <div ref="btnPanel" class="bbsl-btn-content"></div>
      <el-table
        ref="multipleSelection"
        v-loading="loading"
        :cell-style="{'text-align': 'center'}"
        :data="tableData"
        :header-cell-style="{'text-align': 'center'}"
        :max-height="tableMaxHeight"
        :style="{width: '100%'}"
        border
        size="mini"
        @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange"
      >
        <el-table-column label="序号" type="index" width="55"></el-table-column>
        <el-table-column
          label="设备标识"
          prop="deviceCode"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column label="设备名称" show-overflow-tooltip>
          <template slot-scope="scope">
            <span class="active" @click="toDialog(scope.row.deviceCode)">{{
              scope.row.deviceName
            }}</span>
          </template>
        </el-table-column>
        <el-table-column
          label="采集时间"
          prop="collTime"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          label="采集对象"
          prop="gasName"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column label="气体浓度" prop="sdata" show-overflow-tooltip>
        </el-table-column>
        <el-table-column label="单位" prop="gasUnit" show-overflow-tooltip>
        </el-table-column>
      </el-table>
      <el-pagination
        ref="paginationPanel"
        :current-page="queryParam.pageBean.page"
        :page-size="queryParam.pageBean.pageSize"
        :page-sizes="[20, 30, 40, 50]"
        :total="total"
        align="right"
        background
        class="bbsl-pagination"
        layout="total, sizes, prev, pager, next, jumper"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
      ></el-pagination>
    </div>
    <RealTimeMonitorDialog ref="RealTimeMonitorDialog"></RealTimeMonitorDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import dangerousDevice from '@/api/device/dangerousDevice.js'
import RealTimeMonitorDialog from '@/components/detailsDialog/RealTimeMonitorDialog.vue'
import moment from 'moment'
export default {
  name: 'RealTimeMonitor',
  components: {
    RealTimeMonitorDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      conditions: [
        {
          name: '实时数据',
          value: 'realtime',
          icon: 'shishishuju'
        },
        {
          name: '历史数据',
          value: 'history',
          icon: 'guidang'
        }
      ],
      activeName: 'realtime',
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'b.coll_time_',
          relation: 'AND',
          value: [
            moment()
              .subtract(1, 'days')
              .format('YYYY-MM-DD 00:00:00'),
            moment().format('YYYY-MM-DD 00:00:00')
          ]
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'd.name_',
          relation: 'AND',
          value: ''
        }
      ],
      sorter: [
        {
          direction: 'DESC',
          property: 'b.coll_time_'
        }
      ],
    }
  },
  created() {
    if (this.$route.query.code) {
      this.querys.push({
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'b.device_code_',
        relation: 'AND',
        value: this.$route.query.code
      })
    }
  },
  mounted() {},
  methods: {
    handleTabsClick(tab) {
      console.log('切换到标签:', tab.name)
      this.activeName = tab.name
      this.loadData(1)
    },
    toDialog(name) {
      this.$refs.RealTimeMonitorDialog.add(name)
    },
    handleReset() {
      this.querys[0].value = [
        moment()
          .subtract(1, 'days')
          .format('YYYY-MM-DD 00:00:00'),
        moment().format('YYYY-MM-DD 00:00:00')
      ]
      this.querys[1].value = ''
      this.handleSearch()
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam = Object.assign(this.queryParam, {
        sorter: this.sorter
      })
      if (this.querys[0].value && this.activeName === 'history') {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.$route.query.code) {
        this.queryParam.querys.push(this.querys[2])
      }
      console.log(this.queryParam.querys)
      const API =
        this.activeName === 'history'
          ? dangerousDevice.getDeviceData
          : dangerousDevice.loadQuery

      API(this.queryParam, 'jwwxyjc')
        .then(res => {
          const {rows = [], total = 0} = res
          this.tableData = rows
          this.total = total
          this.loading = false
        })
        .finally(() => {
          this.loading = false
        })
    }
  }
}
</script>
<style lang="scss" scoped>
.bbsl-common-page {
  background-color: #fff;
}
.bbsl-table-search {
  display: flex;
  align-items: center;
}
.tabs {
  height: 100%;
}
.search {
  height: 100%;
  display: flex;
  align-items: center;
  .el-form-item {
    margin-bottom: 0;
  }
}

::v-deep .el-tabs__nav-wrap::after {
  display: none;
}

::v-deep .el-tabs,
::v-deep .el-tabs__header,
::v-deep .el-tabs__nav-wrap,
::v-deep .el-tabs__nav-scroll,
::v-deep .el-tabs__nav {
  height: 100%;
}

::v-deep .el-tabs__header {
  margin-bottom: 0 !important;
}
::v-deep .el-tabs__nav {
  padding-top: 12px;
  box-sizing: border-box;
}
</style>
